==> go.php?file=RaidAchievement6.003.zip: RaidAchievement/Localization/localization-esMX.lua <==
﻿if GetLocale() == "esMX" then

function psealocale()

	charakillintime = "¡Requerimientos completados! ¡Mata al boss con los 3 stacks de Cargar Relámpago (quedan 30 seg)!"
	charakillintime2 = "¡Requerimientos completos! ¡Mata al boss mientras tenga el beneficio (quedan 20 seg)!"
	chhrbrannyell = "Correcto, ¡allá vamos! Sólo necesito introducir la secuencia final correcta en el mecanismo de la puerta... y..."
	chratitle = "    Heróicas de Cataclysm"
	crraraidpartachloc1 = "¡Choque Estático!"
	crraraidpartachloc2 = "¡Bomba de veneno!"
	crraraidpartachloc3 = "¡Aniquilador Arcano!"
	crraraidpartachloc4 = "¡Lanzallamas!"
	crratitle = "    Bandas de Cataclysm"
	icratitle = "    Ciudadela de la Corona de Hielo"
	icravalitriayell1 = "He abierto un portal al Sueño Esmeralda. Vuestra salvación está dentro, héroes..."
	icravalitriayell2 = "¡ESTOY RENOVADA! ¡Ysera haz que estas asquerosas criaturas descansen"
	nrallbuttonmaint = "Lista por zonas"
	nrallbuttontak = "Tácticas"
	nxraonyemote = "Recibid mi Aliento Profundo"
	nxraonyxiab = "Onyxia"
	nxratitle = "    Naxxramas + otras mini bandas de WotLK"
	phratitle = "    Heróicas de Pandaria"
	prratitle = "    Bandas de Pandaria"
	psbuttonoff = "ALTO"
	psbuttonon = "Comenzar"
	pseaaddonmy = "Addon"
	pseaaddonoff = "APAGADO"
	pseaaddonok = "BIEN"
	pseaaddonon = "Habilitar addon"
	pseaaddonon2 = "ENCENDIDO"
	pseachangeall = "Cambiar"
	pseachatlist1 = "banda"
	pseachatlist2 = "aviso de banda"
	pseachatlist3 = "oficial"
	pseachatlist4 = "grupo"
	pseachatlist5 = "hermandad"
	pseachatlist6 = "decir"
	pseachatlist7 = "gritar"
	pseachatlist8 = "yo sólo"
	pseadisableall = "Deshabilitar todo"
	pseaenableall = "Habilitar todo"
	psealeftmenu1 = "Addon"
	psealeftmenu11 = "Seguir después de fallar"
	psealeftmenu3 = "Naxxramas"
	psealeftmenu31 = "Naxxramas + otras mini bandas de WotLK"
	psealeftmenu4 = "Mazmorras de WotLK"
	psealeftmenu5 = "Ulduar"
	psealeftmenu6 = "Ciudadela de la Corona de Hielo"
	psealeftmenucata = "Heróicas de Cataclysm"
	psealeftmenucata2 = "Bandas de Cataclysm"
	psealeftmenupanda = "Heróicas de Pandaria"
	psealeftmenupanda2 = "Bandas de Pandaria"
	psealeftmenupanda3 = "Gestas de Pandaria"
	pseamanyachtitle = "    Mantener el seguimiento del logro después de fallarlo"
	pseamimifailloc1 = "¡Robot Bum!"
	pseamimifailloc2 = "¡Golpe de Cohete!"
	pseamimifailloc3 = "¡Mina!"
	pseamimifailloc5 = "¡parte fallada!"
	pseamoduleload = "Módulo cargado:"
	pseamodulenotload = "Error mientras se cargaba el módulo:"
	pseaoldmodules = "Módulos antiguos"
	pseaoldmodules2 = "    Módulos antiguos"
	pseapartfailedloc = "¡parte fallada!"
	pseapsaddonanet = "¡Error! No está instalado el addon PhoenixStyle"
	pseapsaddonanet2 = "Puedes descargarlo desde www.phoenixstyle.com"
	pseareports = "- canal de chat para anunciar los avisos"
	pseashownames = "Mostrar la razón (nombre, etc) del fallo del logro"
	pseashowveren = "Mostrar mensaje si se detecta una versión más nueva del addon en tu hermandad/grupo"
	pseasoundoptions1 = "Reproduce sonido cuando falle un logro"
	pseasoundoptions2 = "Reproduce sonido cuando se cumplan los requisitos"
	pseasoundoptions3 = "Reproduce sonido sólo si me falta ese logro"
	pseasoundoptions6 = "Modo maestro, reproduce sonido cuando el sonido del juego está deshabilitado"
	pseatreb2 = "¡requerimientos completados! ¡mata al boss ahora!"
	pseatreb4 = "¡fallado!"
	pseatrebulda2 = "¡Mata el último add y ENTONCES mata al boos!"
	pseauierror = "    ¡Error!"
	pseauierroraddonoff = "¡Error! El addon se ha deshabilitado - ¡este módulo no está disponible!"
	pseauinomodule1 = "    ¡Error! ¡Módulo no instalado!"
	pseauinomodule2 = "¡Error! ¡El módulo elegido no está instalado!"
	pseaulduarkolf1 = "¡Se ha matado al add!"
	pseaulduarkolf2 = "¡no se completará si matas al boss ahora!"
	pseaulduartitle = "    Ulduar"
	PSFeaserver = "ru-Gordunni"
	psmoduletxtoff = "el módulo está deshabilitado"
	psmoduletxton = "el módulo está habilitado"
	psoldvertxt = "(versión vieja)"
	pzratitle = "    Gestas de Pandaria"
	racolor1 = "rojo"
	racolor2 = "negro"
	racolor3 = "amarillo"
	racolor5 = "verde"
	racolor6 = "púrpura"
	racolorcomb = "QUEDA UNA combinación"
	radatabrokervart = "Clic = Mostrar | Ocultar"
	radeathwingemote1 = "¡rueda a la izquierda!"
	radeathwingemote2 = "¡rueda a la derecha!"
	raerroraddoninst = "¡Error! El addon no está instalado. Tienes que bajarlo e instalarlo:"
	raerrormodulereq = "Necesita un módulo adicional:"
	raiccof = "de"
	raiccused = "usado"
	ramainbattleground = "campo de batalla"
	ramainbattlegroundopt = "Mostrar lista de logros también en campos de batalla (si está habilitado para bandas)"
	ramaintrackingtitle = "En seguimiento"
	ramanyachtitinfo = "Cuando se falla un logro se bloquea el seguimiento hasta que acabe el combate. Este módulo resetea el bloqueo. El reseteo ocurrirá en "
	ramanyachtitinfo2 = "después del 'mensaje de fallo'. Establece cuantos resets se pueden hacer por cada combate y haz clic en el módulo 'empezar'. Este módulo se autodeshabilita después de desconectarte."
	ramanyachtitinfoq = "Se reseteará el bloqueo del seguimiento de logros"
	ramanyachtitinfoq2 = "veces para este combate. Cambiar:"
	ramanyplayers = "muchos jugadores"
	raminibuttset = "Mostrar botón en el minimapa"
	ramodulnotblock = "el seguimiento no se bloqueará"
	ranewversfound = "|cff00ff00¡Atención!|r Se ha encontrado una nueva versión. Se recomienda actualizar desde http://phoenixstyle.com"
	ranotsure = "¡NO EXACTAMENTE!"
	raragnaachtxt1 = "¡mata el boss para conseguirlo!"
	raragnaachtxt2 = "¡Requerimientos completados! ¡Tienes %s seg para matar al boss! Comprueba el contador en tu addon para bosses."
	rasec = "seg."
	raspectext = "Zona de combate demasiado grande. ¡Requiere más addons en la banda!"
	ravalitnottrack = "no se puede hacer el seguimiento en heroico por el addon"
	rayard = "yd"
	whraaddkilled1 = "¡Se ha matado al add!"
	whraaddkilled2 = "¡no se completará si matas al boss ahora!"
	whrabrann = "Brann Barbabronce "
	whrabrannemo = "quieres jugar duro"
	whrabrannemo2 = "seguridad desactivada. Comenzando la purga de la memoria y"
	whragundemo = "así que tienes agallas"
	whratitle = "    Heroicas de WotLK"

end

end

==> go.php?file=RaidAchievement6.008.zip: RaidAchievement/Localization/localization-esMX.lua <==
﻿if GetLocale() == "esMX" then

function psealocale()

	charakillintime = "¡Requerimientos completados! ¡Mata al boss con los 3 stacks de Cargar Relámpago (quedan 30 seg)!"
	charakillintime2 = "¡Requerimientos completos! ¡Mata al boss mientras tenga el beneficio (quedan 20 seg)!"
	chhrbrannyell = "Correcto, ¡allá vamos! Sólo necesito introducir la secuencia final correcta en el mecanismo de la puerta... y..."
	chratitle = "    Heróicas de Cataclysm"
	crraraidpartachloc1 = "¡Choque Estático!"
	crraraidpartachloc2 = "¡Bomba de veneno!"
	crraraidpartachloc3 = "¡Aniquilador Arcano!"
	crraraidpartachloc4 = "¡Lanzallamas!"
	crratitle = "    Bandas de Cataclysm"
	icratitle = "    Ciudadela de la Corona de Hielo"
	icravalitriayell1 = "He abierto un portal al Sueño Esmeralda. Vuestra salvación está dentro, héroes..."
	icravalitriayell2 = "¡ESTOY RENOVADA! ¡Ysera haz que estas asquerosas criaturas descansen"
	nrallbuttonmaint = "Lista por zonas"
	nrallbuttontak = "Tácticas"
	nxraonyemote = "Recibid mi Aliento Profundo"
	nxraonyxiab = "Onyxia"
	nxratitle = "    Naxxramas + otras mini bandas de WotLK"
	phratitle = "    Heróicas de Pandaria"
	prratitle = "    Bandas de Pandaria"
	psbuttonoff = "ALTO"
	psbuttonon = "Comenzar"
	pseaaddonmy = "Addon"
	pseaaddonoff = "APAGADO"
	pseaaddonok = "BIEN"
	pseaaddonon = "Habilitar addon"
	pseaaddonon2 = "ENCENDIDO"
	pseachangeall = "Cambiar"
	pseachatlist1 = "banda"
	pseachatlist2 = "aviso de banda"
	pseachatlist3 = "oficial"
	pseachatlist4 = "grupo"
	pseachatlist5 = "hermandad"
	pseachatlist6 = "decir"
	pseachatlist7 = "gritar"
	pseachatlist8 = "yo sólo"
	pseadisableall = "Deshabilitar todo"
	pseaenableall = "Habilitar todo"
	psealeftmenu1 = "Addon"
	psealeftmenu11 = "Seguir después de fallar"
	psealeftmenu3 = "Naxxramas"
	psealeftmenu31 = "Naxxramas + otras mini bandas de WotLK"
	psealeftmenu4 = "Mazmorras de WotLK"
	psealeftmenu5 = "Ulduar"
	psealeftmenu6 = "Ciudadela de la Corona de Hielo"
	psealeftmenucata = "Heróicas de Cataclysm"
	psealeftmenucata2 = "Bandas de Cataclysm"
	psealeftmenupanda = "Heróicas de Pandaria"
	psealeftmenupanda2 = "Bandas de Pandaria"
	psealeftmenupanda3 = "Gestas de Pandaria"
	pseamanyachtitle = "    Mantener el seguimiento del logro después de fallarlo"
	pseamimifailloc1 = "¡Robot Bum!"
	pseamimifailloc2 = "¡Golpe de Cohete!"
	pseamimifailloc3 = "¡Mina!"
	pseamimifailloc5 = "¡parte fallada!"
	pseamoduleload = "Módulo cargado:"
	pseamodulenotload = "Error mientras se cargaba el módulo:"
	pseaoldmodules = "Módulos antiguos"
	pseaoldmodules2 = "    Módulos antiguos"
	pseapartfailedloc = "¡parte fallada!"
	pseapsaddonanet = "¡Error! No está instalado el addon PhoenixStyle"
	pseapsaddonanet2 = "Puedes descargarlo desde www.phoenixstyle.com"
	pseareports = "- canal de chat para anunciar los avisos"
	pseashownames = "Mostrar la razón (nombre, etc) del fallo del logro"
	pseashowveren = "Mostrar mensaje si se detecta una versión más nueva del addon en tu hermandad/grupo"
	pseasoundoptions1 = "Reproduce sonido cuando falle un logro"
	pseasoundoptions2 = "Reproduce sonido cuando se cumplan los requisitos"
	pseasoundoptions3 = "Reproduce sonido sólo si me falta ese logro"
	pseasoundoptions6 = "Modo maestro, reproduce sonido cuando el sonido del juego está deshabilitado"
	pseatreb2 = "¡requerimientos completados! ¡mata al boss ahora!"
	pseatreb4 = "¡fallado!"
	pseatrebulda2 = "¡Mata el último add y ENTONCES mata al boos!"
	pseauierror = "    ¡Error!"
	pseauierroraddonoff = "¡Error! El addon se ha deshabilitado - ¡este módulo no está disponible!"
	pseauinomodule1 = "    ¡Error! ¡Módulo no instalado!"
	pseauinomodule2 = "¡Error! ¡El módulo elegido no está instalado!\r\nDownload it from http://phoenixstyle.com or curse.com"
	pseaulduarkolf1 = "¡Se ha matado al add!"
	pseaulduarkolf2 = "¡no se completará si matas al boss ahora!"
	pseaulduartitle = "    Ulduar"
	PSFeaserver = "ru-Gordunni"
	psmoduletxtoff = "el módulo está deshabilitado"
	psmoduletxton = "el módulo está habilitado"
	psoldvertxt = "(versión vieja)"
	pzratitle = "    Gestas de Pandaria"
	racolor1 = "rojo"
	racolor2 = "negro"
	racolor3 = "amarillo"
	racolor5 = "verde"
	racolor6 = "púrpura"
	racolorcomb = "QUEDA UNA combinación"
	radatabrokervart = "Clic = Mostrar | Ocultar"
	radeathwingemote1 = "¡rueda a la izquierda!"
	radeathwingemote2 = "¡rueda a la derecha!"
	raerroraddoninst = "¡Error! El addon no está instalado. Tienes que bajarlo e instalarlo:"
	raerrormodulereq = "Necesita un módulo adicional:"
	raiccof = "de"
	raiccused = "usado"
	ramainbattleground = "campo de batalla"
	ramainbattlegroundopt = "Mostrar lista de logros también en campos de batalla (si está habilitado para bandas)"
	ramaintrackingtitle = "En seguimiento"
	ramanyachtitinfo = "Cuando se falla un logro se bloquea el seguimiento hasta que acabe el combate. Este módulo resetea el bloqueo. El reseteo ocurrirá en "
	ramanyachtitinfo2 = "después del 'mensaje de fallo'. Establece cuantos resets se pueden hacer por cada combate y haz clic en el módulo 'empezar'. Este módulo se autodeshabilita después de desconectarte."
	ramanyachtitinfoq = "Se reseteará el bloqueo del seguimiento de logros"
	ramanyachtitinfoq2 = "veces para este combate. Cambiar:"
	ramanyplayers = "muchos jugadores"
	raminibuttset = "Mostrar botón en el minimapa"
	ramodulnotblock = "el seguimiento no se bloqueará"
	ranewversfound = "|cff00ff00¡Atención!|r Se ha encontrado una nueva versión. Se recomienda actualizar desde http://phoenixstyle.com"
	ranotsure = "¡NO EXACTAMENTE!"
	raragnaachtxt1 = "¡mata el boss para conseguirlo!"
	raragnaachtxt2 = "¡Requerimientos completados! ¡Tienes %s seg para matar al boss! Comprueba el contador en tu addon para bosses."
	rasec = "seg."
	raspectext = "Zona de combate demasiado grande. ¡Requiere más addons en la banda!"
	ravalitnottrack = "no se puede hacer el seguimiento en heroico por el addon"
	rayard = "yd"
	whraaddkilled1 = "¡Se ha matado al add!"
	whraaddkilled2 = "¡no se completará si matas al boss ahora!"
	whrabrann = "Brann Barbabronce "
	whrabrannemo = "quieres jugar duro"
	whrabrannemo2 = "seguridad desactivada. Comenzando la purga de la memoria y"
	whragundemo = "así que tienes agallas"
	whratitle = "    Heroicas de WotLK"

end

end
